#
# spec file for package qucs
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qucs
Version:        0.0.18
Release:        lp150.1.7
Summary:        Circuit Simulator with Graphical User Interface (Qt)
License:        GPL-2.0 and GPL-2.0+
Group:          Productivity/Scientific/Electronics
Url:            http://qucs.sf.net
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
# Qucs icon from http://qucs.sourceforge.net/
Source2:        %{name}.png
# PATCH-FIX-OPENSUSE qucs-digisim-verilog.patch -- using verilog for digital simulation by default
Patch1:         qucs-digisim-verilog.patch
# PATCH-FIX-UPSTREAM qucs-no-return-in-nonvoid-function.patch
Patch2:         qucs-no-return-in-nonvoid-function.patch
Patch3:         qucs_powerpc_gcc_undef_vector.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org - fix call of overloaded 'abs(double&)' is ambiguous
Patch4:         qucs-0.0.18-gcc6.patch
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gperf
# fix directory owner
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt4-devel
BuildRequires:  update-desktop-files
Requires:       adms
Requires:       asco
Requires:       iverilog
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Qucs is an integrated circuit simulator which means you are able to
setup a circuit with a graphical user interface (GUI) and simulate the
large-signal, small-signal and noise behaviour of the circuit. After
that simulation has finished you can view the simulation results on a
presentation page or window.

%package     -n libqucs0
Summary:        Qucs library
Group:          System/Libraries

%description -n libqucs0
Qucs is an integrated circuit simulator which means you are able to
setup a circuit with a graphical user interface (GUI) and simulate the
large-signal, small-signal and noise behaviour of the circuit. After
that simulation has finished you can view the simulation results on a
presentation page or window.

%package        devel
Summary:        Development files fir QUCS library
Group:          Development/Libraries/Other
Requires:       libqucs0 = %{version}

%description    devel
Qucs is an integrated circuit simulator which means you are able to
setup a circuit with a graphical user interface (GUI) and simulate the
large-signal, small-signal and noise behaviour of the circuit. After
that simulation has finished you can view the simulation results on a
presentation page or window.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%ifarch ppc64le
%patch3 -p1
%endif
%patch4 -p1

cp %{SOURCE1} .
cp %{SOURCE2} .

%build
%configure \
    --disable-adms \
    --disable-asco

make %{?_smp_mflags}

%install
%make_install
%fdupes %{buildroot}/%{_datadir}/qucs/

rm -rf %{buildroot}/%{_libdir}/libqucs.la

install -Dm 644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 644 %{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
# hicolor-icon-theme does not contain this size
rm -rf %{buildroot}%{_datadir}/icons/hicolor/512x512/

%suse_update_desktop_file %{name}

%post -n libqucs0 -p /sbin/ldconfig
%postun -n libqucs0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc NEWS.md README COPYING
%{_bindir}/ps2sp
%{_bindir}/qucs*
%{_datadir}/qucs/
%{_mandir}/man1/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/qucs.*
%{_datadir}/pixmaps/%{name}.png

%files -n libqucs0
%defattr(-,root,root)
%{_libdir}/libqucs.so.0*

%files devel
%defattr(-,root,root)
%{_libdir}/libqucs.so
%{_includedir}/qucs-core/

%changelog
* Fri Jun 24 2016 i@marguerite.su
- add patch: qucs-0.0.18-gcc6.patch
  * fix boo#985097
  * fix call of overloaded 'abs(double&)' is ambiguous
* Tue Aug 11 2015 normand@linux.vnet.ibm.com
- for ppc64le archi add a new patch to avoid build error.
  qucs_powerpc_gcc_undef_vector.patch
* Wed Oct  1 2014 dmitry_r@opensuse.org
- Update to version 0.0.18
  * See NEWS.md for details
- Fix no-return-in-nonvoid-function
  * qucs-no-return-in-nonvoid-function.patch
* Thu Jul  4 2013 dmitry_r@opensuse.org
- Update to version 0.0.17
  * port to qt4
  * removed obsolete qucs-conj.diff
  * removed obsolete qucs-m4.diff
  * removed obsolete qucs-tr1.diff
* Tue Oct  2 2012 dmitry_r@opensuse.org
- Change license to "GPL-2.0 and GPL-2.0+" [bnc#783145]
* Sun Sep 30 2012 dmitry_r@opensuse.org
- Fix desktop file
- Fix SLE 11 build
* Sat Sep 29 2012 dmitry_r@opensuse.org
- Using verilog for digital simulation by default
  * qucs-digisim-verilog.patch
- Add desktop file
* Sat Aug 18 2012 dmitry_r@opensuse.org
- Spec file cleanup
- Fix buildrequires for openSUSE 12.2
* Sat Jun 25 2011 arun@gmx.de
- updated to 0.0.16
* Thu May 19 2011 stefan.bruens@rwth-aachen.de
- fix compilation and enhance spec file
* Sat Apr 25 2009 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.15
* Mon Nov 24 2008 Werner Hoch <werner.ho@gmx.de>
- build fixes for factory
* Sun Apr 13 2008 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.14
* Mon Dec 31 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.13
* Mon Jun 18 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.12
* Sun Mar 18 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.0.11
* Mon Oct 23 2006 Werner Hoch <werner.ho@gmx.de>
- initial build version 0.0.10
